#!/bin/sh 

DESC="OpenVPN daemon" 
NAME=openvpn 
TYPE=net

OPENVPN_DIR=/etc/openvpn

. $(dirname $0)/common 

case "$1" in 
	start)
		modprobe tun >& /dev/null
		# enable IP forwarding?
		# echo 1 > /proc/sys/net/ipv4/ip_forward
		for i in $OPENVPN_DIR/*.conf; do
			if ! test -f $i; then continue; fi
			nm=$(basename $i .conf)
			RC_PIDFILE=/var/run/$NAME-$nm.pid
			OPENVPN_OPTS="--daemon openvpn-$nm --cd $OPENVPN_DIR \
				--log /var/log/openvpn-$nm.log --writepid $RC_PIDFILE --config $i" 			
			start $NAME -- $OPENVPN_OPTS
		done
		if test -z "$nm"; then echo "$0: You must configure openvpn first."; exit 1; fi
		;; 
	stop)
		for i in $OPENVPN_DIR/*.conf; do
			nm=$(basename $i .conf)
			RC_PIDFILE=/var/run/$NAME-$nm.pid
			stop $NAME
		done
		modprobe -r tun >& /dev/null
		# disable IP forwarding
		# echo 0 > /proc/sys/net/ipv4/ip_forward
		;; 
	status)
		st=0
		for i in $OPENVPN_DIR/*.conf; do
			nm=$(basename $i .conf)
			RC_PIDFILE=/var/run/$NAME-$nm.pid
			status $NAME-$nm
			st=$((st+$?))
		done
		return $st
		;;
	reload) reload $NAME ;; 
	restart) restart $NAME ;;
	*) usage $0 "start|stop|status|restart|reload" ;;
esac 
